@@ -2,8 +2,8 @@
 #    Autocomplete feature for admin panel
 #
 #    Most of the code has been written by Jannis Leidel, then updated a bit
-#    for django_extensions, finally reassembled and extended by Mikele Pasin. 
-# 
+#    for django_extensions, finally reassembled and extended by Mikele Pasin.
+#
 #    http://jannisleidel.com/2008/11/autocomplete-form-widget-foreignkey-model-fields/
 #    http://code.google.com/p/django-command-extensions/
 #    http://magicrebirth.wordpress.com/
@@ -25,7 +25,7 @@
 
 # 3.Add the 'admin/autocomplete' folder to your templates folder
 
-# 4.Add the extrafilters.py file in the templatetags directory of your application (or just add its contents to 
+# 4.Add the extrafilters.py file in the templatetags directory of your application (or just add its contents to
 #   your custom template tags if you already have some).
 #  All is needed is the 'cut' filter, for making the code used in the inline-autocomplete form javascript friendly
 
@@ -43,7 +43,7 @@
 # TROUBLE SHOOTING:
 #  ==============
 
-# ** sometimes things don't work cause you have to add 'from django.conf.urls.defaults import *' to the modules where you use the autocomplete 
+# ** sometimes things don't work cause you have to add 'from django.conf.urls.defaults import *' to the modules where you use the autocomplete
 # ** if you're using the inline-autocompletion, make sure that the main admin class the inline belong to is a subclass FkAutocompleteAdmin
 # ** you may need to hack it a bit to make it work for you - it's been done in a rush!
 
@@ -75,7 +75,7 @@ from django.conf.urls.defaults import *
 
 class FkSearchInput(ForeignKeyRawIdWidget):
     """
-    A Widget for displaying ForeignKeys in an autocomplete search input 
+    A Widget for displaying ForeignKeys in an autocomplete search input
     instead in a <select> box.
     """
 
@@ -100,10 +100,10 @@ class FkSearchInput(ForeignKeyRawIdWidget):
         obj = self.rel.to._default_manager.get(**{key: value})
         return truncate_words(obj, 14)
 
-    def __init__(self, rel, admin_site, search_fields, attrs=None):  # ajout 1.4
-    #def __init__(self, rel, search_fields, attrs=None):
+    def __init__(self, rel, admin_site, search_fields, attrs=None):  # ajout 1.4 : admin_site
         self.search_fields = search_fields
-        super(FkSearchInput, self).__init__(rel, attrs)
+        super(FkSearchInput, self).__init__(rel, admin_site, attrs)
+
 
     def render(self, name, value, attrs=None):
         if attrs is None:
@@ -154,7 +154,7 @@ class FkSearchInput(ForeignKeyRawIdWidget):
 
 class NoLookupsForeignKeySearchInput(ForeignKeyRawIdWidget):
     """
-    A Widget for displaying ForeignKeys in an autocomplete search input 
+    A Widget for displaying ForeignKeys in an autocomplete search input
     instead in a <select> box.
     """
 
@@ -183,7 +183,7 @@ class NoLookupsForeignKeySearchInput(ForeignKeyRawIdWidget):
     #def __init__(self, rel, search_fields, attrs=None):
     def __init__(self, rel, admin_site, search_fields, attrs=None):  # ajout 1.4
         self.search_fields = search_fields
-        super(NoLookupsForeignKeySearchInput, self).__init__(rel, attrs)
+        super(NoLookupsForeignKeySearchInput, self).__init__(rel, admin_site, attrs)
 
     def render(self, name, value, attrs=None):
         if attrs is None:
@@ -232,7 +232,7 @@ class NoLookupsForeignKeySearchInput(ForeignKeyRawIdWidget):
 
 class InlineSearchInput(ForeignKeyRawIdWidget):
     """
-    A Widget for displaying ForeignKeys in an autocomplete search input 
+    A Widget for displaying ForeignKeys in an autocomplete search input
     instead in a <select> box.
     """
 
@@ -324,7 +324,7 @@ class InlineSearchInput(ForeignKeyRawIdWidget):
 
 
 class FkAutocompleteAdmin(admin.ModelAdmin):
-    """ 
+    """
     Admin class for models using the autocomplete feature.
 
     There are two additional fields:
@@ -351,7 +351,7 @@ class FkAutocompleteAdmin(admin.ModelAdmin):
     #         pass
     #     elif url == 'foreignkey_autocomplete':
     #         return self.foreignkey_autocomplete(request)
-    #     return super(ForeignKeyAutocompleteAdmin, self).__call__(request, url)
+    #     return super(FkAutocompleteAdmin, self).__call__(request, url)
 
     def get_urls(self):
         urls = super(FkAutocompleteAdmin,self).get_urls()
@@ -362,7 +362,7 @@ class FkAutocompleteAdmin(admin.ModelAdmin):
 
     def foreignkey_autocomplete(self, request):
         """
-        Searches in the fields of the given related model and returns the 
+        Searches in the fields of the given related model and returns the
         result as a simple string to be used by the jQuery Autocomplete plugin
         """
         query = request.GET.get('q', None)
@@ -410,31 +410,32 @@ class FkAutocompleteAdmin(admin.ModelAdmin):
         return HttpResponseNotFound()
 
     def get_help_text(self, field_name, model_name):
-        searchable_fields = self.related_search_fields.get(field_name, None)
-        if searchable_fields:
-            help_kwargs = {
-                'model_name': model_name,
-                'field_list': get_text_list(searchable_fields, _('and')),
-            }
-            return _('Use the left field to do %(model_name)s lookups in the fields %(field_list)s.') % help_kwargs
-        return ''
+        return None
+    #     searchable_fields = self.related_search_fields.get(field_name, None)
+    #     if searchable_fields:
+    #         help_kwargs = {
+    #             'model_name': model_name,
+    #             'field_list': get_text_list(searchable_fields, _('and')),
+    #         }
+    #         return _('Use the left field to do %(model_name)s lookups in the fields %(field_list)s.') % help_kwargs
+    #     return ''
 
 
 # this method gets called when creating the formfields - probably this is what you need to extend
-#  in the replicated version of ForeignKeyAutocompleteAdmin
+#  in the replicated version of FkAutocompleteAdmin
 
     def formfield_for_dbfield(self, db_field, **kwargs):
         """
         Overrides the default widget for Foreignkey fields if they are
         specified in the related_search_fields class attribute.
         """
-        if (isinstance(db_field, models.ForeignKey) and 
+        if (isinstance(db_field, models.ForeignKey) and
             db_field.name in self.related_search_fields):
             model_name = db_field.rel.to._meta.object_name
             help_text = self.get_help_text(db_field.name, model_name)
             if kwargs.get('help_text'):
                 help_text = u'%s %s' % (kwargs['help_text'], help_text)
-            kwargs['widget'] = FkSearchInput(db_field.rel,
+            kwargs['widget'] = FkSearchInput(db_field.rel, self.admin_site,
                                     self.related_search_fields[db_field.name])
             kwargs['help_text'] = help_text
         return super(FkAutocompleteAdmin,
@@ -451,8 +452,8 @@ class FkAutocompleteAdmin(admin.ModelAdmin):
 
 
 
-class NoLookupsForeignKeyAutocompleteAdmin(admin.ModelAdmin):
-    """ 
+class NoLookupsFkAutocompleteAdmin(admin.ModelAdmin):
+    """
         In certain cases you do not want to have the usual raw_id lenses for related items lookup.
         Code mostly as above, changes only the template that renders it.
     """
@@ -465,10 +466,10 @@ class NoLookupsForeignKeyAutocompleteAdmin(admin.ModelAdmin):
     #         pass
     #     elif url == 'foreignkey_autocomplete':
     #         return self.foreignkey_autocomplete(request)
-    #     return super(ForeignKeyAutocompleteAdmin, self).__call__(request, url)
+    #     return super(FkAutocompleteAdmin, self).__call__(request, url)
 
     def get_urls(self):
-        urls = super(NoLookupsForeignKeyAutocompleteAdmin,self).get_urls()
+        urls = super(NoLookupsFkAutocompleteAdmin,self).get_urls()
         search_url = patterns('',
             (r'^foreignkey_autocomplete/$', self.admin_site.admin_view(self.foreignkey_autocomplete))
         )
@@ -476,7 +477,7 @@ class NoLookupsForeignKeyAutocompleteAdmin(admin.ModelAdmin):
 
     def foreignkey_autocomplete(self, request):
         """
-        Searches in the fields of the given related model and returns the 
+        Searches in the fields of the given related model and returns the
         result as a simple string to be used by the jQuery Autocomplete plugin
         """
         query = request.GET.get('q', None)
@@ -535,23 +536,23 @@ class NoLookupsForeignKeyAutocompleteAdmin(admin.ModelAdmin):
 
 
 # this method gets called when creating the formfields - probably this is what you need to extend
-#  in the replicated version of ForeignKeyAutocompleteAdmin
+#  in the replicated version of FkAutocompleteAdmin
 
     def formfield_for_dbfield(self, db_field, **kwargs):
         """
         Overrides the default widget for Foreignkey fields if they are
         specified in the related_search_fields class attribute.
         """
-        if (isinstance(db_field, models.ForeignKey) and 
+        if (isinstance(db_field, models.ForeignKey) and
             db_field.name in self.related_search_fields):
             model_name = db_field.rel.to._meta.object_name
             help_text = self.get_help_text(db_field.name, model_name)
             if kwargs.get('help_text'):
                 help_text = u'%s %s' % (kwargs['help_text'], help_text)
-            kwargs['widget'] = NoLookupsForeignKeySearchInput(db_field.rel,
+            kwargs['widget'] = NoLookupsForeignKeySearchInput(db_field.rel, self.admin_site,
                                     self.related_search_fields[db_field.name])
             kwargs['help_text'] = help_text
-        return super(NoLookupsForeignKeyAutocompleteAdmin,
+        return super(NoLookupsFkAutocompleteAdmin,
             self).formfield_for_dbfield(db_field, **kwargs)
 
 
@@ -569,12 +570,12 @@ class NoLookupsForeignKeyAutocompleteAdmin(admin.ModelAdmin):
 
 
 class InlineAutocompleteAdmin(admin.TabularInline):
-    """ 
+    """
     Admin class for models using the autocomplete feature in inlines.
 
     At the moment, this autocomplete works only if the admin of the model including the inline-admin is
-    itself a subclass of an autocomplete Admin (e.g., ForeignKeyAutocompleteAdmin)
-    
+    itself a subclass of an autocomplete Admin (e.g., FkAutocompleteAdmin)
+
     """
 
     related_search_fields = {}
@@ -585,7 +586,7 @@ class InlineAutocompleteAdmin(admin.TabularInline):
     #         pass
     #     elif url == 'foreignkey_autocomplete':
     #         return self.foreignkey_autocomplete(request)
-    #     return super(ForeignKeyAutocompleteAdmin, self).__call__(request, url)
+    #     return super(FkAutocompleteAdmin, self).__call__(request, url)
 
     def get_urls(self):
         urls = super(InlineAutocompleteAdmin,self).get_urls()
@@ -596,7 +597,7 @@ class InlineAutocompleteAdmin(admin.TabularInline):
 
     def foreignkey_autocomplete(self, request):
         """
-        Searches in the fields of the given related model and returns the 
+        Searches in the fields of the given related model and returns the
         result as a simple string to be used by the jQuery Autocomplete plugin
         """
         query = request.GET.get('q', None)
@@ -655,14 +656,14 @@ class InlineAutocompleteAdmin(admin.TabularInline):
 
 
 # this method gets called when creating the formfields - probably this is what you need to extend
-#  in the replicated version of ForeignKeyAutocompleteAdmin
+#  in the replicated version of FkAutocompleteAdmin
 
     def formfield_for_dbfield(self, db_field, **kwargs):
         """
         Overrides the default widget for Foreignkey fields if they are
         specified in the related_search_fields class attribute.
         """
-        if (isinstance(db_field, models.ForeignKey) and 
+        if (isinstance(db_field, models.ForeignKey) and
             db_field.name in self.related_search_fields):
             model_name = db_field.rel.to._meta.object_name
             help_text = self.get_help_text(db_field.name, model_name)
@@ -679,18 +680,18 @@ class InlineAutocompleteAdmin(admin.TabularInline):
 
 
 #  ===========
-# using the autocomplete admin with other custom admin classes: 
-# just mix and match as you like.... 
+# using the autocomplete admin with other custom admin classes:
+# just mix and match as you like....
 #  e.g. in my case I used it with the admin for trees provided by FeinCms:
 
-try:
-    from feincms.admin import editor
-    #  just merging the effects of the two classes..
-    class AutocompleteTreeEditor(FkAutocompleteAdmin, editor.TreeEditor):
-        def __init__(self, *args, **kwargs):
-            super(AutocompleteTreeEditor, self).__init__(*args, **kwargs)
-except ImportError:
-    pass
+# try:
+#     from feincms.admin import editor
+#     #  just merging the effects of the two classes..
+#     class AutocompleteTreeEditor(FkAutocompleteAdmin, editor.TreeEditor):
+#         def __init__(self, *args, **kwargs):
+#             super(AutocompleteTreeEditor, self).__init__(*args, **kwargs)
+# except ImportError:
+#     pass
 #  ===========
 
 
